HashPrefixMap

Struct HashPrefixMap 

pub struct HashPrefixMap<K, V, S = RandomState>(/* private fields */);
A prefix map that uses length buckets and hashmaps for lookups

For asciimath, the default hasher makes this the third fastest prefix map. If the qp-trie feature isn’t enabled, this will be the default. Finding the longest prefix takes O(len_search_key), but if all keys are long and roughly the same length this may be faster than QpTriePrefixMap.

Example

use asciimath_parser::prefix_map::HashPrefixMap;
use asciimath_parser::{ASCIIMATH_TOKENS};

let token_map = HashPrefixMap::from_iter(ASCIIMATH_TOKENS);

Implementations

Source

impl<K, V, S> HashPrefixMap<K, V, S>
where K: Borrow<str> + Hash + Eq, S: BuildHasher + Default,

pub fn from_iter_hasher<T, I>(iter: T) -> Self
where T: IntoIterator<IntoIter = I>, I: Iterator<Item = (K, V)>,

Create from an iterator and custom hasher