LinearPrefixMap

Struct LinearPrefixMap 

pub struct LinearPrefixMap<K, V>(/* private fields */);
A very simple prefix map

This prefix map stores prefix in descending order by length. While very simple, it was still reasonably fast only requires keys with equality. This might be a good choice on machines with limited memory especially if you’re parsing a very small subset of asciimath. Finding the longest prefix takes O(num_prefixes).

Implementations

Source

impl<K, V> LinearPrefixMap<K, V>
where K: Borrow<str> + Eq,

pub fn from_vec<B>(inp: B) -> Self
where B: Into<Vec<(K, V)>>,

Create from a vector of entries