pub struct LinearPrefixMap<K, V>(/* private fields */);Expand description
A very simple prefix map
This prefix map stores prefix in descending order by length. While very simple, it was still
reasonably fast only requires keys with equality. This might be a good choice on machines with
limited memory especially if you’re parsing a very small subset of asciimath. Finding the
longest prefix takes O(num_prefixes).
Implementations